pub(crate) enum ForbidParamsAfterReason {
LoweringParamDefault,
AnonConst,
ConstParamTy,
}Variants
LoweringParamDefault
When lowering generic param defaults, you cannot refer to any param after the currently lowered param, including the current param.
AnonConst
Most anon const (except array repeat expressions) cannot refer to any generic param.
ConstParamTy
The type of a const param cannot refer to a type param.