pub(crate) enum ImplTraitLoweringMode {
Opaque,
Disallowed,
}Variants
Opaque
impl Trait gets lowered into an opaque type that doesn’t unify with
anything except itself. This is used in places where values flow ‘out’,
i.e. for arguments of the function we’re currently checking, and return
types of functions we’re calling.
Disallowed
impl Trait is disallowed and will be an error.