pub(crate) fn field_types_with_diagnostics<'db>(
db: &'db dyn HirDatabase,
variant_id: VariantId,
) -> &'db TyLoweringResult<'db, FieldTypes>Expand description
Build the type of all specific fields of a struct or enum variant.
pub(crate) fn field_types_with_diagnostics<'db>(
db: &'db dyn HirDatabase,
variant_id: VariantId,
) -> &'db TyLoweringResult<'db, FieldTypes>Build the type of all specific fields of a struct or enum variant.