fn type_for_fn<'db>(
db: &'db dyn HirDatabase,
def: FunctionId,
) -> EarlyBinder<'db, Ty<'db>>Expand description
Build the declared type of a function. This should not need to look at the function body.
fn type_for_fn<'db>(
db: &'db dyn HirDatabase,
def: FunctionId,
) -> EarlyBinder<'db, Ty<'db>>Build the declared type of a function. This should not need to look at the function body.