pub struct FieldTypes {
map: ArenaMap<LocalFieldId, FieldType>,
}Expand description
Wrapper struct around ArenaMap which implements [SalsaValue].
Required to make the SalsaValue derive for TyLoweringResult work.
Fields
map: ArenaMap<LocalFieldId, FieldType>Methods from Deref<Target = ArenaMap<LocalFieldId, FieldType>>
pub fn contains_idx(&self, idx: Idx<T>) -> bool
pub fn contains_idx(&self, idx: Idx<T>) -> bool
Returns whether the map contains a value for the specified index.
pub fn get(&self, idx: Idx<T>) -> Option<&V>
pub fn get(&self, idx: Idx<T>) -> Option<&V>
Returns a reference to the value associated with the provided index if it is present.
pub fn values(&self) -> impl Iterator<Item = &V> + DoubleEndedIterator
pub fn values(&self) -> impl Iterator<Item = &V> + DoubleEndedIterator
Returns an iterator over the values in the map.
pub fn iter(&self) -> impl Iterator<Item = (Idx<T>, &V)> + DoubleEndedIterator
pub fn iter(&self) -> impl Iterator<Item = (Idx<T>, &V)> + DoubleEndedIterator
Returns an iterator over the arena indexes and values in the map.