struct ImplTraitLoweringState {
mode: ImplTraitLoweringMode,
opaque_type_data: Arena<ImplTrait>,
}Fields
mode: ImplTraitLoweringModeWhen turning impl Trait into opaque types, we have to collect the
bounds at the same time to get the IDs correct (without becoming too
complicated).
opaque_type_data: Arena<ImplTrait>Implementations