Struct TrackedStructToken
pub(crate) struct TrackedStructToken {
_private: (),
}Expand description
A token that is required to construct tracked structs. This exists to prevent one from accidentally creating a tracked struct outside of a query which may happen for some codepaths.
Fields
_private: ()Auto Trait Implementations
impl Freeze for TrackedStructToken
impl RefUnwindSafe for TrackedStructToken
impl Send for TrackedStructToken
impl Sync for TrackedStructToken
impl Unpin for TrackedStructToken
impl UnsafeUnpin for TrackedStructToken
impl UnwindSafe for TrackedStructToken